<p align="center">
    <a href="https://github.com/maximshumilo/fastapi-restful-extension/actions?query=workflow%3ATest+event%3Apush+branch%3Amaster" target="_blank">
        <img src="https://github.com/maximshumilo/fastapi-restful-extension/actions/workflows/test.yml/badge.svg">
    </a>
    <a href="https://codecov.io/gh/maximshumilo/fastapi-restful-extension">
        <img src="https://img.shields.io/codecov/c/gh/maximshumilo/fastapi-restful-extension?color=31c955"/>
    </a>
    <a href="https://pypi.org/project/fastapi-restful-extension/" target="_blank">
        <img src="https://img.shields.io/pypi/v/fastapi-restful-extension?color=31c955&label=pypi%20package">
    </a>
    <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/fastapi-restful-extension?color=31c955">
</p>

<p align="center">
    FastAPI-RESTful-Extension - is extension for FastAPI that allows you to easily create a REST API.
</p>

---

**Documentation**: <a href="https://maximshumilo.github.io/fastapi-restful-extension/" target="_blank">https://maximshumilo.github.io/fastapi-restful-extension/ </a>

**PyPI**: <a href="https://pypi.org/project/fastapi-restful-extension/" target="_blank">https://pypi.org/project/fastapi-restful-extension/ </a>

---

# Installation

FastAPI-RESTful-Extension has the following dependencies:

- FastAPI <= `0.78.0`
- Python version: `3.7, 3.8, 3.9` or `3.10`

---

### From PyPI
Install package with pip from `pypi.org`

```console
$ pip install fastapi-restful-extension

Collecting fastapi-restful-extension
  Downloading fastapi_restful_extension-0.3.0-py3-none-any.whl (8.0 kB)
...
...
...
Installing collected packages: fastapi-restful-extension
Successfully installed fastapi-restful-extension-0.3.0
```

---
